<?php



/**
 * Written by David Smith
 * nopeer@gmail.com
 *
 * For the Pulsar Web Archive project.
 * Ideally, this class should replace the use of MysqlDB in all the files and contain
 * functions for every operation we would like to do on the pulsar archive database.
 * However, due to time constraints, this won't be done for the time being.
 **/



require_once 'MysqlDB.php';
require_once 'constants.php';



/**
 * @class PulsarArchiveDB   This class encapsulates all the sql used by the project to interface with the
 *                          database.
 **/

class PulsarArchiveDB extends MysqlDB
{
  function __construct()
  {
    parent::__construct();
  }

  function GetUnregisteredUsers()
  {
    return $this->SelectByFields( USERS_TABLE, Array( 'registered' => 0 ) );
  }

  function GetRegisteredUsers()
  {
    return $this->SelectByFields( USERS_TABLE, Array( 'registered' => 1 ) );
  }

  function GetAdmins()
  {
    return $this->SelectByFields( USERS_TABLE, Array( 'administrator' => 1 ) );
  }

  // TODO do we need this function? as users don't actually register anymore
  function RemoveExpiredUsers()
  {
    return $this->DoQuery( 'DELETE FROM ' . USERS_TABLE . ' WHERE DATE_SUB(CURDATE(), INTERVAL ' . PENDING_REGISTRATION_PERIOD . ' DAY ' );
    // TODO log the error
  }

  /**
   * @brief           Gets the range of mjds from all observations (both S70 and observations tables)
   * @param min_mjd   Put the minimum mjd here
   * @param max_mjd   Put the maximum mjd here
   **/

  function GetMinMaxMJD( &$min_mjd, &$max_mjd )
  {
    $query = 'SELECT min(t.mjd) as min, max(t.mjd) as max ' .
              'FROM ((SELECT mjd FROM ' . S70_TABLE . ') ' .
              'UNION (SELECT mjd FROM ' . OBSERVATIONS_TABLE . ')) AS t';

    $this->DoQuery( $query );
    $this->EnsureNumRows( 'equals', 1 );
    $row = $this->FetchRowAsArray();

    $min_mjd = $row['min'];
    $max_mjd = $row['max'];
  }


  /**
   * @brief    Creates a list of the fields from the observations table we want to use on the query form.
   * @returns  The list of field names
   **/

  function GetObservationFields()
  {
    $this->DoQuery( 'DESCRIBE ' . OBSERVATIONS_TABLE );
    $results = $this->GetLastResult();

    $field_names = Array();
    foreach( $results as $next_row )
      if( $next_row['Field'] != 'data_loc' && $next_row['Field'] != 'file_size_bytes' )
        $field_names[] = $next_row;

    return $field_names;
  }



  /**
   * @brief    Returns all the data_type values from the observation and S70 tables.
   * @returns  The array of results.
   **/

  function GetDataTypes()
  {
    $query = '(SELECT distinct data_type ' .
	     'FROM ' . OBSERVATIONS_TABLE . ')' .
	     'UNION (SELECT distinct data_type FROM ' . S70_TABLE . ')';

    $this->DoQuery( $query );

    return $this->GetLastResult();
  }



  /**
   * @brief    Updates the password for the user given
   **/

  function UpdatePassword( $username, $password )
  {
    $query = ' UPDATE ' . USERS_TABLE .
	     ' SET password = "' . $password . '"' .
	     ' WHERE username = "' . $username . '"';

    $this->DoQuery( $query );
  }
};



?>